@@ -1,3 +1,7 @@
+import os, sys
+sys.path.append(os.path.dirname( \
+os.path.dirname(os.path.realpath(__file__))))
+
 from pyngrok import ngrok
 import datetime
 from .code import ImCode
